import json
import time
import os
import threading

__all__ = [
    "get_pid", "get_tid",
    "record_timestamp",
    "record_begin",
    "record_end",
    "record_duration",
    "record_thread_name",
    "record_process_name",
    "record_process_sort_index",
    "record_thread_sort_index",
    "record_dump"
]

contents = []

def get_pid():
    return os.getpid()

def get_tid():
    tid = threading.get_ident()
    if not tid: tid = 0
    return tid


def record_timestamp(name:str,
                 cat:str,
                 **kwargs) -> None:
    j = {
        "name":name,
        "cat":cat,
        "ts": time.time()*1000,
        "pid": get_pid(),
        "tid": get_tid()
    }
    if kwargs:
        j["args"] = kwargs
    return j

def record_begin(name:str,
                 cat:str="",
                 **kwargs):
    j = record_timestamp(name, cat, **kwargs)
    j['ph'] = "B"
    contents.append(json.dumps(j))

def record_end(name:str,
               cat:str="",
               **kwargs):
    j = record_timestamp(name, cat, **kwargs)
    j['ph'] = "E"
    contents.append(json.dumps(j))

def record_duration(name:str,
                    cat:str="",
                    dur:float=0,
                    **kwargs):
    j = record_timestamp(name, cat, **kwargs)
    j['ph'] = "X"
    j['dur'] = dur  
    contents.append(json.dumps(j))
    
def record_thread_name(name:str, **kwargs):
    j = {
        "name": "thread_name",
        "ph": "M",
        "pid": get_pid(),
        "tid": get_tid(),
    }
    kwargs['name'] = name
    j['args'] = kwargs
    contents.append(json.dumps(j))

def record_process_name(name:str, **kwargs):
    j = {
        "name": "process_name",
        'ph': 'M',
        'pid': get_pid(),
    }
    kwargs['name'] = name
    j['args'] = kwargs
    contents.append(json.dumps(j))
    
def record_process_sort_index(index:int, **kwargs):
    j = {
        'name': 'process_sort_index',
        'ph': 'M',
        'pid': get_pid(),
    }
    kwargs['sort_index'] = index
    j['args'] = kwargs
    contents.append(json.dumps(j))

def record_thread_sort_index(index:int, **kwargs):
    j = {
        'name': 'thread_sort_index',
        'ph': 'M',
        'pid': get_pid(),
        'tid': get_tid(),
    }
    kwargs['sort_index'] = index
    j['args'] = kwargs
    contents.append(json.dumps(j))

def record_dump(filename:str):
    with open(filename, 'w') as f:
        # f.write(str(contents))
        f.write("[\n")
        f.write(",\n".join(contents))
        f.write("\n]\n")
        
        
        
if __name__ == '__main__':
    for i in range(2):
        print(f"{i}")
        record_begin(name=f"name_{i}", cat="")
        time.sleep(1)
        record_end(name=f"name_{i}", cat="")
        time.sleep(0.5)
    record_thread_name(name="thread")
    record_process_name(name="process")
    record_dump("./togo/test.json")


import logging
import colorlog

__all__ = ["get_file_handler", "get_stream_handler", "get_logger"]

console_color_config = {
    'DEBUG': 'white',  # cyan white
    'INFO': 'green',
    'WARNING': 'yellow',
    'ERROR': 'red',
    'CRITICAL': 'bold_red',
}

fmt = '[%(asctime)s.%(msecs)03d] "%(pathname)s", line %(lineno)d [%(levelname)s] : %(message)s'
color_fmt = f'%(log_color)s{fmt}'
date_fmt = "%Y-%m-%d %H:%M:%S"

def get_file_handler(log_path = "./log.txt")->logging.FileHandler :
    file_formatter = logging.Formatter(
        fmt = fmt,
        datefmt = date_fmt
    )
    handler = logging.FileHandler(log_path)
    handler.setLevel(logging.DEBUG)
    handler.setFormatter(file_formatter)
    return handler
    
    
def get_stream_handler()->logging.StreamHandler:
    console_formatter = colorlog.ColoredFormatter(
        fmt = color_fmt,
        datefmt = date_fmt,
        log_colors = console_color_config
    )
    handler = logging.StreamHandler()
    handler.setLevel(logging.INFO)
    handler.setFormatter(console_formatter)
    return handler

def get_logger(logger_name="zq_logger",
               log_path = "./log.txt",
               enable_file = True,
               enable_console = True):
    logger = logging.getLogger(logger_name)
    logger.setLevel(logging.DEBUG)
    if not logger.handlers:
        if enable_file:
            logger.addHandler(get_file_handler(log_path))
        if enable_console:
            logger.addHandler(get_stream_handler())
    return logger



if __name__ == '__main__':
    # show colors
    logger = logging.getLogger(__name__)
    logger.setLevel(logging.DEBUG) # 第一层过滤
    logger.addHandler(get_file_handler())
    stream_handler = get_stream_handler()
    stream_handler.setLevel(logging.DEBUG)
    logger.addHandler(stream_handler)
    logger.debug("debug")
    logger.info("info")
    logger.warning("warning")
    logger.error("error")
    logger.critical("critical")
    print()


    # test functions
    logger = get_logger()
    logger.debug("debug")
    logger.info("info")
    logger.warning("warning")
    logger.error("error")
    logger.critical("critical")


from zq_tools.zq_tracing import *
import time
        
if __name__ == '__main__':
    for i in range(2):
        print(f"{i}")
        record_begin(name=f"name_{i}", cat="")
        time.sleep(1)
        record_end(name=f"name_{i}", cat="")
        time.sleep(0.5)
    record_thread_name(name="thread")
    record_process_name(name="process")
    record_dump("./test.json")



from zq_tools.zq_logger import *

def main():
    import logging
    # show colors
    logger = logging.getLogger(__name__)
    logger.setLevel(logging.DEBUG) # filter level
    logger.addHandler(get_file_handler())
    stream_handler = get_stream_handler()
    stream_handler.setLevel(logging.DEBUG)
    logger.addHandler(stream_handler)
    logger.debug("debug")
    logger.info("info")
    logger.warning("warning")
    logger.error("error")
    logger.critical("critical")
    print()

    # test functions
    logger = get_logger()
    logger.debug("debug")
    logger.info("info")
    logger.warning("warning")
    logger.error("error")
    logger.critical("critical")
    
if __name__ == '__main__':
    main()


import setuptools

with open("README.md", 'r') as f:
    long_description = f.read()

setuptools.setup(
    name="zq-tools",
    version="0.3.0",
    author="zzqq2199",
    author_email="zhouquanjs@qq.com",
    description="A collection of tools for zzqq2199",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=["zq_tools"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)